summaryrefslogtreecommitdiffstats
path: root/win/tkWinInt.h
diff options
context:
space:
mode:
Diffstat (limited to 'win/tkWinInt.h')
-rw-r--r--win/tkWinInt.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/win/tkWinInt.h b/win/tkWinInt.h
index ca4916a..cbe2290 100644
--- a/win/tkWinInt.h
+++ b/win/tkWinInt.h
@@ -11,7 +11,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tkWinInt.h,v 1.13 2002/04/12 07:18:49 hobbs Exp $
+ * RCS: @(#) $Id: tkWinInt.h,v 1.14 2003/02/26 02:47:05 hobbs Exp $
*/
#ifndef _TKWININT
@@ -127,10 +127,11 @@ typedef struct {
/*
* The following variable is a translation table between X gc functions and
* Win32 raster op modes.
*/
extern int tkpWinRopModes[];
+extern int tkpWinBltModes[];
/*
* The following defines are used with TkWinGetBorderPixels to get the
@@ -127,10 +127,11 @@ typedef struct {
/*
* The following variable is a translation table between X gc functions and
- * Win32 raster op modes.
+ * Win32 raster and BitBlt op modes.
*/
extern int tkpWinRopModes[];